@@ -2,8 +2,6 @@
 #define glines_h
 
 #define STEPSIZE 4
-#define BOXSIZE 42
-#define BALLSIZE 32
 #define FIELDSIZE 9
 
 typedef struct
@@ -18,6 +16,7 @@ typedef struct
 	int pathsearch;
 	int phase;
 	int active;
+	int tag;
 } field_props;
 
 void draw_box(GtkWidget *widget, int x, int y);
