@@ -1068,12 +1068,18 @@ prepare_map (char *level)
 void
 new_game_cb (GtkWidget *widget, gpointer data)
 {
+  gint oldwidth = width;
+  gint oldheight = height;
+
   widget = space;
 
   prepare_map (data);
-  gtk_widget_set_size_request (GTK_WIDGET (space),
-                               width * TILE_SIZE, height * TILE_SIZE);
-  gtk_widget_realize (window);
+
+  if ((oldwidth != width) || (oldheight != height))
+    gtk_widget_set_size_request (GTK_WIDGET (space),
+                                 width * TILE_SIZE, height * TILE_SIZE);
+  else
+    redraw_all();
 
   set_move (0);
 
