@@ -513,9 +513,13 @@ gint
 computer_move_3(guint me)
 {
 	guint best_x, best_y;
+
 	find_best_move( board, me, 7, 10000, -10000, &best_x, &best_y);
-	
-	move(best_x, best_y, me);
+
+       if (best_x == 8 && best_y == 8)
+               computer_move_1(me);
+       else	
+	       move(best_x, best_y, me);
 	
 	return (FALSE);
 }
@@ -532,6 +536,7 @@ find_best_move(gint8 board[8][8], guint me, gint ply_depth,
 	gint tmp_move;
 	gint8 tboard[8][8];
 	gboolean exit_loops = FALSE;
+	gboolean pass = TRUE;
 
 	not_me = (me == WHITE_TURN) ? BLACK_TURN : WHITE_TURN;
 	
@@ -541,6 +546,8 @@ find_best_move(gint8 board[8][8], guint me, gint ply_depth,
 		for (i = 0; i < 8 && !exit_loops; i++)
 			for (j = 0; j < 8 && !exit_loops; j++)
 				if (is_valid_move_board(board, i, j, me)) {
+
+					pass = FALSE;
 					memcpy (tboard, board, sizeof (gint8) * 8 * 8);
 					move_board(tboard, i, j, me, 0);
 	
@@ -554,21 +561,20 @@ find_best_move(gint8 board[8][8], guint me, gint ply_depth,
 						pass_thresh = tmp_move;
 						best_x = i;
 						best_y = j;
-						
 						exit_loops = (pass_thresh >= use_thresh);
 					}
+
 				}
 		
-		// check if we have to pass
-		if (best_x == 8 && best_y == 8) {
+		if (pass) {
 			tmp_move = find_best_move(board, not_me, ply_depth-1,
-				-pass_thresh, -use_thresh, 0, 0);
-			
+						  -pass_thresh, -use_thresh, 0, 0);
 			tmp_move = -tmp_move;
-			
+
 			if (tmp_move > pass_thresh)
 				pass_thresh = tmp_move;
-		}	
+		}
+
 	}
 
 	if (ret_best_x && ret_best_y) {
