@@ -27,9 +27,9 @@
  * structures are modelled on those he used (and the typeinfo
  * structure is identical) but the algorithm is completely different.
  * 
- * The new algorithm works by randomly descending the the tree of all
+ * The new algorithm works by randomly descending the tree of all
  * possible games (i.e all possible sequences of pairs of tiles) and
- * tries and find a path to a solution. If it can't get there it
+ * tries to find a path to a solution. If it can't get there it
  * backtracks up the tree trying all the possibilities in a random order.
  * In principle this could be very expensive computationally, but in
  * practice only a few levels of backtracking should be necessary,
@@ -38,11 +38,9 @@
  * after a very long time). This may be unavoidable, but I suspect that
  * given the contraints of the board (specifically the maximum height) the
  * largest unsolvable board that can be made is not a big problem. Once
- * it has a path it fills it with a pairs of tiles chosen at random.
+ * it has a path it fills it with pairs of tiles chosen at random.
  *
- * Hopefully this new algorithm can be simply modified to be used for the
- * shuffle command. This is where the ability to detect unsolvable
- * configurations will be really useful.
+ * The algorithm is also used to shuffle the tiles.
  *
  * - Callum, 20030819
  */
@@ -56,82 +54,84 @@ struct _typeinfo {
   int type;
   int placed;
   int image[2];
+  int tile; /* A back-reference so we can figure out which pictures 
+               are used. */
 };
 typedef struct _typeinfo typeinfo;
 
 typeinfo type_info [MAX_TILES/2] = {
-  	{ 0, 0, {0, 0} },
-	{ 0, 0, {0, 0} },
-	{ 1, 0, {1, 1} },
-	{ 1, 0, {1, 1} },
-	{ 2, 0, {2, 2} },
-	{ 2, 0, {2, 2} },
-	{ 3, 0, {3, 3} },
-	{ 3, 0, {3, 3} },
-	{ 4, 0, {4, 4} },
-	{ 4, 0, {4, 4} },
-	{ 5, 0, {5, 5} },
-	{ 5, 0, {5, 5} },
-	{ 6, 0, {6, 6} },
-	{ 6, 0, {6, 6} },
-	{ 7, 0, {7, 7} },
-	{ 7, 0, {7, 7} },
-	{ 8, 0, {8, 8} },
-	{ 8, 0, {8, 8} },
-	{ 9, 0, {9, 9} },
-	{ 9, 0, {9, 9} },
-	{ 10, 0, {10, 10} },
-	{ 10, 0, {10, 10} },
-	{ 11, 0, {11, 11} },
-	{ 11, 0, {11, 11} },
-	{ 12, 0, {12, 12} },
-	{ 12, 0, {12, 12} },
-	{ 13, 0, {13, 13} },
-	{ 13, 0, {13, 13} },
-	{ 14, 0, {14, 14} },
-	{ 14, 0, {14, 14} },
-	{ 15, 0, {15, 15} },
-	{ 15, 0, {15, 15} },
-	{ 16, 0, {16, 16} },
-	{ 16, 0, {16, 16} },
-	{ 17, 0, {17, 17} },
-	{ 17, 0, {17, 17} },
-	{ 18, 0, {18, 18} },
-	{ 18, 0, {18, 18} },
-	{ 19, 0, {19, 19} },
-	{ 19, 0, {19, 19} },
-	{ 20, 0, {20, 20} },
-	{ 20, 0, {20, 20} },
-	{ 21, 0, {21, 21} },
-	{ 21, 0, {21, 21} },
-	{ 22, 0, {22, 22} },
-	{ 22, 0, {22, 22} },
-	{ 23, 0, {23, 23} },
-	{ 23, 0, {23, 23} },
-	{ 24, 0, {24, 24} },
-	{ 24, 0, {24, 24} },
-	{ 25, 0, {25, 25} },
-	{ 25, 0, {25, 25} },
-	{ 26, 0, {26, 26} },
-	{ 26, 0, {26, 26} },
-	{ 27, 0, {27, 27} },
-	{ 27, 0, {27, 27} },
-	{ 28, 0, {28, 28} },
-	{ 28, 0, {28, 28} },
-	{ 29, 0, {29, 29} },
-	{ 29, 0, {29, 29} },
-	{ 30, 0, {30, 30} },
-	{ 30, 0, {30, 30} },
-	{ 31, 0, {31, 31} },
-	{ 31, 0, {31, 31} },
-	{ 32, 0, {32, 32} },
-	{ 32, 0, {32, 32} },
-	{ 33, 0, {33, 34} },
-	{ 33, 0, {35, 36} },
-	{ 34, 0, {37, 37} },
-	{ 34, 0, {37, 37} },
-	{ 35, 0, {38, 39} },
-	{ 35, 0, {40, 41} }
+  	{ 0, 0, {0, 0}, -1 },
+	{ 0, 0, {0, 0}, -1 },
+	{ 1, 0, {1, 1}, -1 },
+	{ 1, 0, {1, 1}, -1 },
+	{ 2, 0, {2, 2}, -1 },
+	{ 2, 0, {2, 2}, -1 },
+	{ 3, 0, {3, 3}, -1 },
+	{ 3, 0, {3, 3}, -1 },
+	{ 4, 0, {4, 4}, -1 },
+	{ 4, 0, {4, 4}, -1 },
+	{ 5, 0, {5, 5}, -1 },
+	{ 5, 0, {5, 5}, -1 },
+	{ 6, 0, {6, 6}, -1 },
+	{ 6, 0, {6, 6}, -1 },
+	{ 7, 0, {7, 7}, -1 },
+	{ 7, 0, {7, 7}, -1 },
+	{ 8, 0, {8, 8}, -1 },
+	{ 8, 0, {8, 8}, -1 },
+	{ 9, 0, {9, 9}, -1 },
+	{ 9, 0, {9, 9}, -1 },
+	{ 10, 0, {10, 10}, -1 },
+	{ 10, 0, {10, 10}, -1 },
+	{ 11, 0, {11, 11}, -1 },
+	{ 11, 0, {11, 11}, -1 },
+	{ 12, 0, {12, 12}, -1 },
+	{ 12, 0, {12, 12}, -1 },
+	{ 13, 0, {13, 13}, -1 },
+	{ 13, 0, {13, 13}, -1 },
+	{ 14, 0, {14, 14}, -1 },
+	{ 14, 0, {14, 14}, -1 },
+	{ 15, 0, {15, 15}, -1 },
+	{ 15, 0, {15, 15}, -1 },
+	{ 16, 0, {16, 16}, -1 },
+	{ 16, 0, {16, 16}, -1 },
+	{ 17, 0, {17, 17}, -1 },
+	{ 17, 0, {17, 17}, -1 },
+	{ 18, 0, {18, 18}, -1 },
+	{ 18, 0, {18, 18}, -1 },
+	{ 19, 0, {19, 19}, -1 },
+	{ 19, 0, {19, 19}, -1 },
+	{ 20, 0, {20, 20}, -1 },
+	{ 20, 0, {20, 20}, -1 },
+	{ 21, 0, {21, 21}, -1 },
+	{ 21, 0, {21, 21}, -1 },
+	{ 22, 0, {22, 22}, -1 },
+	{ 22, 0, {22, 22}, -1 },
+	{ 23, 0, {23, 23}, -1 },
+	{ 23, 0, {23, 23}, -1 },
+	{ 24, 0, {24, 24}, -1 },
+	{ 24, 0, {24, 24}, -1 },
+	{ 25, 0, {25, 25}, -1 },
+	{ 25, 0, {25, 25}, -1 },
+	{ 26, 0, {26, 26}, -1 },
+	{ 26, 0, {26, 26}, -1 },
+	{ 27, 0, {27, 27}, -1 },
+	{ 27, 0, {27, 27}, -1 },
+	{ 28, 0, {28, 28}, -1 },
+	{ 28, 0, {28, 28}, -1 },
+	{ 29, 0, {29, 29}, -1 },
+	{ 29, 0, {29, 29}, -1 },
+	{ 30, 0, {30, 30}, -1 },
+	{ 30, 0, {30, 30}, -1 },
+	{ 31, 0, {31, 31}, -1 },
+	{ 31, 0, {31, 31}, -1 },
+	{ 32, 0, {32, 32}, -1 },
+	{ 32, 0, {32, 32}, -1 },
+	{ 33, 0, {33, 34}, -1 },
+	{ 33, 0, {35, 36}, -1 },
+	{ 34, 0, {37, 37}, -1 },
+	{ 34, 0, {37, 37}, -1 },
+	{ 35, 0, {38, 39}, -1 },
+	{ 35, 0, {40, 41}, -1 }
 };
 
 typedef struct _dep_entry {
@@ -349,6 +349,7 @@ static void place_tiles (guint a, guint b, gint depth)
   tiles[a].type = tiles[b].type = type_info[depth].type;
   tiles[a].image = type_info[depth].image[0];
   tiles[b].image = type_info[depth].image[1];
+  type_info[depth].tile = a;
 }
 
 static gboolean walk_tree (gint depth)
@@ -359,7 +360,7 @@ static gboolean walk_tree (gint depth)
   gint oldnumfree;
   guchar a, b;
 
-  /* The termination conditions. */
+  /* The termination condition. */
   if (numfree < 2) {/* We don't have enough tiles to continue. */
     return FALSE;
   }
@@ -384,10 +385,10 @@ static gboolean walk_tree (gint depth)
    * long time, it will in general only affect the very end of any walk. */
   
   /* Scramble the freelist. */
-  for (i = 0; i<numfree*2; i++) {
-    j = g_rand_int_range (generator, 0, numfree);
-    swap = freelist[depth][0];
-    freelist[depth][0] = freelist[depth][j];
+  for (i = 0; i<numfree; i++) {
+    j = g_rand_int_range (generator, i, numfree);
+    swap = freelist[depth][i];
+    freelist[depth][i] = freelist[depth][j];
     freelist[depth][j] = swap;
   }
   
@@ -461,9 +462,35 @@ void generate_game (guint32 seed)
 int shuffle (void)
 {
   int n = 0;
-  int i,j;
-  typeinfo tmp;
-  
+  int i, j;
+  typeinfo temp;
+
+  /* Shuffle the images around so that we use the same set of tile images
+   * as last time. */
+  for (i=0; i<MAX_TILES/2 - 1; i++) {
+    if (tiles[type_info[i].tile].visible)
+      type_info[i].tile = 1;
+    else
+      type_info[i].tile = 0;
+  }
+  i = 0; j = MAX_TILES/2 - 1;
+  while (1) {
+    while (j && type_info[j].tile)
+      j--;
+    while ((i < MAX_TILES/2) && (type_info[i].tile == 0))
+      i++;
+    if (j<i)
+      break;
+    temp = type_info[i];
+    type_info[i] = type_info[j];
+    type_info[j] = temp;
+    j--;
+    i++;
+  }
+
+  /* Figure out which ones are available and which aren't. 
+   * Also figure out what depth in the tree we have to start
+   * at, i.e. how far through the game we are. */
   for (i=0; i<MAX_TILES; i++) {
     if (tiles[i].visible) {
       filled[i] = TRUE;
@@ -474,6 +501,7 @@ int shuffle (void)
   }
   n >>= 1;
 
+  /* Check which ones are playable. */
   numfree = 0;
   for (i=0; i<MAX_TILES; i++) {
     freetiles[n][i] = FALSE;
@@ -482,5 +510,6 @@ int shuffle (void)
     } 
   }
 
+  /* Work out a new, random, solution. */
   return walk_tree (n);
 }
