@@ -432,6 +432,11 @@ load_scenario (char *fname)
 	else
 		fn = g_build_filename (PIXMAPDIR, fname, NULL);
 
+	if (! g_file_test (fn, G_FILE_TEST_EXISTS)) {
+		g_free (fn);
+		fn = g_build_filename (PIXMAPDIR, "stones.png", NULL);
+	}
+
 	if (! g_file_test (fn, G_FILE_TEST_EXISTS)) {
 		GtkWidget *box = gtk_message_dialog_new 
 			(GTK_WINDOW (app),
@@ -442,7 +447,6 @@ load_scenario (char *fname)
 			   "Please check your Same GNOME installation."), fn);
 
 		gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_OK);
-                gtk_dialog_set_has_separator (GTK_DIALOG (box), FALSE);
 		gtk_dialog_run (GTK_DIALOG (box));
 		gtk_widget_destroy (box);
                 /* We may not have called gtk_main yet, but if we do we want
@@ -474,7 +478,6 @@ load_scenario (char *fname)
 		
 		gtk_dialog_set_default_response (GTK_DIALOG (box),
 						 GTK_RESPONSE_OK);
-                gtk_dialog_set_has_separator (GTK_DIALOG (box), FALSE);
 		gtk_dialog_run (GTK_DIALOG (box));
 		gtk_widget_destroy (box);
                 /* We may not have called gtk_main yet, but if we do we want
@@ -706,7 +709,7 @@ game_about_callback (GtkWidget *widget, void *data)
                 NULL
         };
         /* Translator credits */
-        gchar *translator_credits = _("translator_credits");
+        gchar *translator_credits = _("translator-credits");
 
 	if (about) {
 		gtk_window_present (GTK_WINDOW (about));
@@ -727,12 +730,12 @@ game_about_callback (GtkWidget *widget, void *data)
 	}
 	
 	about = gnome_about_new (_("Same GNOME"), VERSION,
-				 "Copyright \xc2\xa9 1997-2003 Free Software "
+				 "Copyright \xc2\xa9 1997-2004 Free Software "
 				 "Foundation, Inc.",
 				 _("Original idea from KDE's same game "
 				   "program."),				 (const char **)authors,
 				 (const char **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
                                  pixbuf);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
